package com.example.mathseduc

import android.content.Context
import android.content.Intent
import android.os.Bundle
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import android.widget.ArrayAdapter
import android.widget.ListView
import android.widget.TextView
import androidx.activity.OnBackPressedCallback
import androidx.appcompat.app.AppCompatActivity
import com.example.mathseduc.controllers.ControllerLobby
import com.example.mathseduc.controllers.ControllerPlayer
import com.example.mathseduc.controllers.ControllerUtiliser
import com.example.mathseduc.models.Player
import com.google.android.material.dialog.MaterialAlertDialogBuilder
import okhttp3.MultipartBody

class ServerDetailsActivity : AppCompatActivity() {

    private var playerList: List<Player> = emptyList()

    private val onBackPressedCallback: OnBackPressedCallback = object : OnBackPressedCallback(true) {
        override fun handleOnBackPressed() {
            MyBackPressed()
        }
    }
    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        onBackPressedDispatcher.addCallback(this, onBackPressedCallback)

        setContentView(R.layout.activity_server_details)

        val serverName = intent.getStringExtra("serverName")

        // Now you can use the data as needed, for example, display it in a TextView
        val serverNameTextView = findViewById<TextView>(R.id.titleServerDetails)
        serverNameTextView.text = serverName

        val lobbyId = intent.getIntExtra("lobbyId", -1)

        if (savedInstanceState != null) {
            playerList = savedInstanceState?.getParcelableArrayList("playerList") ?: emptyList() //TODO deprecated c'est pas normal !!!
        } else {
            // Si l'état d'instance est nul, récupérez la liste des joueurs normalement
            val playerId = ControllerPlayer.getPlayersIdFromLobbyId(lobbyId)
            if (playerId != null) {
                playerList = playerId.mapNotNull { playerId ->
                    ControllerPlayer.getPlayerInfoById(playerId.toString())
                }
            }
        }

        val listViewPlayers = findViewById<ListView>(R.id.listViewPlayers)
        val playerAdapter = PlayerAdapter(this, playerList)
        listViewPlayers.adapter = playerAdapter
    }

    override fun onSaveInstanceState(outState: Bundle) {
        super.onSaveInstanceState(outState)
        // Save the player list to the instance state
        outState.putParcelableArrayList("playerList", ArrayList(playerList))
    }

    private fun MyBackPressed() {

        val lobbyId = intent.getIntExtra("lobbyId", -1)

        ControllerUtiliser.DeleteUtiliserForLobby(MainActivity.idPlayerConnected, lobbyId)

        if (ControllerLobby.PlayerCreatorIdPresentInLobby(MainActivity.idPlayerConnected, lobbyId)) {

            val idNextPlayerCreator = ControllerUtiliser.getIdNextPlayerInLobby(lobbyId)

            if (idNextPlayerCreator == -1) {
                ControllerLobby.deleteLobby(lobbyId)
            } else {
                val formDataBuilder = MultipartBody.Builder().setType(MultipartBody.FORM)

                formDataBuilder.addFormDataPart("idplayercreator", idNextPlayerCreator.toString())

                ControllerLobby.updateLobbyIdCreatorLobby(lobbyId, formDataBuilder)
            }
        }
        finish()
    }

    class PlayerAdapter(context: Context, players: List<Player>) :
        ArrayAdapter<Player>(context, 0, players) {

        override fun getView(position: Int, convertView: View?, parent: ViewGroup): View {
            var currentPlayerView = convertView
            if (currentPlayerView == null) {
                currentPlayerView =
                    LayoutInflater.from(context).inflate(R.layout.list_view_player, parent, false)
            }

            val playerNameTextView = currentPlayerView!!.findViewById<TextView>(R.id.playerName)
            playerNameTextView.text = getItem(position)?.nickname ?: "Unknown"

            // You can customize the view further if needed

            return currentPlayerView
        }
    }
}